# Generated by Django 4.2.1 on 2023-05-10 15:51

from django.db import migrations


class Migration(migrations.Migration):

	dependencies = [
		('django_attachments', '0003_attachment_options'),
	]

	operations = [
		migrations.RenameIndex(
			model_name='attachment',
			new_name='django_atta_library_9d0164_idx',
			old_fields=('library', 'rank'),
		),
	]
