<input class="django-attachments-widget" type="text" id="{{ widget.id }}" name="{{ widget.name }}" value="{% if widget.value %}{{ widget.value }}{% endif %}" data-list-url="{{ library_url }}" data-upload-url="{{ library_url }}" data-update-url="{{ library_url }}" data-create-library-url="{{ create_url }}">
