{% extends "base.html" %}

{% block body %}
<ul>
	<li><a href="{% url "live_upload_attachments" %}">Live upload attachments</a></li>
	<li><a href="{% url "on_save_upload_attachments" %}">On save upload attachments</a></li>
	<li><a href="{% url "gallery_upload" %}">Gallery</a></li>
</ul>
{% endblock %}
